#[non_exhaustive]pub struct Dataset {
pub name: String,
pub display_name: String,
pub description: String,
pub version_id: String,
pub usage: Vec<Usage>,
pub status: Option<Status>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub version_create_time: Option<Timestamp>,
pub version_description: String,
pub data_source: Option<DataSource>,
/* private fields */
}Expand description
A representation of a dataset resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringResource name. Format: projects/{project}/datasets/{dataset_id}
display_name: StringHuman readable name, shown in the console UI.
Must be unique within a project.
description: StringA description of this dataset.
version_id: StringThe version ID of the dataset.
usage: Vec<Usage>Specified use case for this dataset.
status: Option<Status>Output only. The status of this dataset version.
create_time: Option<Timestamp>Output only. Time when the dataset was first created.
update_time: Option<Timestamp>Output only. Time when the dataset metadata was last updated.
version_create_time: Option<Timestamp>Output only. Time when this version was created.
version_description: StringOutput only. The description for this version of dataset. It is provided when importing data to the dataset.
data_source: Option<DataSource>Details about the source of the data for the dataset.
Implementations
Sourceimpl Dataset
impl Dataset
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_version_id<T: Into<String>>(self, v: T) -> Self
pub fn set_version_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Dataset::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Dataset::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Dataset::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Dataset::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Dataset::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Dataset::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_version_create_time<T>(self, v: T) -> Self
pub fn set_version_create_time<T>(self, v: T) -> Self
Sets the value of version_create_time.
Example
use wkt::Timestamp;
let x = Dataset::new().set_version_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_version_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_version_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of version_create_time.
Example
use wkt::Timestamp;
let x = Dataset::new().set_or_clear_version_create_time(Some(Timestamp::default()/* use setters */));
let x = Dataset::new().set_or_clear_version_create_time(None::<Timestamp>);Sourcepub fn set_version_description<T: Into<String>>(self, v: T) -> Self
pub fn set_version_description<T: Into<String>>(self, v: T) -> Self
Sets the value of version_description.
Example
let x = Dataset::new().set_version_description("example");Sourcepub fn set_data_source<T: Into<Option<DataSource>>>(self, v: T) -> Self
pub fn set_data_source<T: Into<Option<DataSource>>>(self, v: T) -> Self
Sets the value of data_source.
Note that all the setters affecting data_source are mutually
exclusive.
Example
use google_maps_mapsplatformdatasets_v1::model::LocalFileSource;
let x = Dataset::new().set_data_source(Some(
google_maps_mapsplatformdatasets_v1::model::dataset::DataSource::LocalFileSource(LocalFileSource::default().into())));Sourcepub fn local_file_source(&self) -> Option<&Box<LocalFileSource>>
pub fn local_file_source(&self) -> Option<&Box<LocalFileSource>>
The value of data_source
if it holds a LocalFileSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_local_file_source<T: Into<Box<LocalFileSource>>>(self, v: T) -> Self
pub fn set_local_file_source<T: Into<Box<LocalFileSource>>>(self, v: T) -> Self
Sets the value of data_source
to hold a LocalFileSource.
Note that all the setters affecting data_source are
mutually exclusive.
Example
use google_maps_mapsplatformdatasets_v1::model::LocalFileSource;
let x = Dataset::new().set_local_file_source(LocalFileSource::default()/* use setters */);
assert!(x.local_file_source().is_some());
assert!(x.gcs_source().is_none());Sourcepub fn gcs_source(&self) -> Option<&Box<GcsSource>>
pub fn gcs_source(&self) -> Option<&Box<GcsSource>>
The value of data_source
if it holds a GcsSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_source<T: Into<Box<GcsSource>>>(self, v: T) -> Self
pub fn set_gcs_source<T: Into<Box<GcsSource>>>(self, v: T) -> Self
Sets the value of data_source
to hold a GcsSource.
Note that all the setters affecting data_source are
mutually exclusive.
Example
use google_maps_mapsplatformdatasets_v1::model::GcsSource;
let x = Dataset::new().set_gcs_source(GcsSource::default()/* use setters */);
assert!(x.gcs_source().is_some());
assert!(x.local_file_source().is_none());