#[non_exhaustive]pub struct LocalFileSource {
pub filename: String,
pub file_format: FileFormat,
/* private fields */
}Expand description
The details about the data source when it is a local file.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filename: StringThe file name of the uploaded file.
file_format: FileFormatThe format of the file that is being uploaded.
Implementations
Sourceimpl LocalFileSource
impl LocalFileSource
Sourcepub fn set_filename<T: Into<String>>(self, v: T) -> Self
pub fn set_filename<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_file_format<T: Into<FileFormat>>(self, v: T) -> Self
pub fn set_file_format<T: Into<FileFormat>>(self, v: T) -> Self
Sets the value of file_format.
Example
ⓘ
use google_maps_mapsplatformdatasets_v1::model::FileFormat;
let x0 = LocalFileSource::new().set_file_format(FileFormat::Geojson);
let x1 = LocalFileSource::new().set_file_format(FileFormat::Kml);
let x2 = LocalFileSource::new().set_file_format(FileFormat::Csv);Trait Implementations
Sourceimpl Clone for LocalFileSource
impl Clone for LocalFileSource
Sourcefn clone(&self) -> LocalFileSource
fn clone(&self) -> LocalFileSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalFileSource
impl Debug for LocalFileSource
Sourceimpl Default for LocalFileSource
impl Default for LocalFileSource
Sourcefn default() -> LocalFileSource
fn default() -> LocalFileSource
Returns the “default value” for a type. Read more
Sourceimpl Message for LocalFileSource
impl Message for LocalFileSource
Sourceimpl PartialEq for LocalFileSource
impl PartialEq for LocalFileSource
impl StructuralPartialEq for LocalFileSource